# CSV-JSON Converter

Conversor de CSV para JSON / JSON para CSV.

## Introduction

Trabalho desenvolvido para a disciplina Python para Ciência de Dados do curso de pós-graduação em Ciência de Dados e Big Data da PUC Minas - 2021.

### What this project can do

Lê arquivos **csv/json** e os converte para **csv/json**.
Este projeto é um programa de execução no terminal.
Instalar preferencialmente com pipx:

```bash
pipx install csv_json_converter_mtba
```

Para usar, digite:

```bash
csv_json_converter --help
```

Esse comando listará todas as opções disponíveis.